#
# spec file for package podofo
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libver 0_9_3

Name:           podofo
Version:        0.9.3
Release:        9.1
Summary:        Tools to work with PDF files
License:        GPL-2.0+
Group:          Productivity/Publishing/PDF
Url:            http://podofo.sourceforge.net/
Source0:        http://downloads.sourceforge.net/podofo/%{name}-%{version}.tar.gz

BuildRequires:  cmake >= 2.5
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
#BuildRequires:  libcppunit-devel
BuildRequires:  libidn-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  lua-devel
BuildRequires:  openssl-devel
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Command line tools for working with PDF files.

%package -n libpodofo%{libver}

Summary:        PDF parsing and creation library
License:        LGPL-2.1+
Group:          System/Libraries

%description -n libpodofo%{libver}
A cross platform PDF parsing and creation library.

%package -n libpodofo-devel
Summary:        Development files for podofo
License:        LGPL-2.1+
Group:          Development/Libraries/Other
Requires:       libpodofo%{libver} = %{version}

%description -n libpodofo-devel
This package contains development files for podofo library.

%prep
%setup -q

# Remove build time references so build-compare can do its work
echo "HTML_TIMESTAMP = NO" >> Doxyfile

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"

mkdir build
cd build
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} -DPODOFO_BUILD_STATIC=FALSE -DPODOFO_USE_VISIBILITY=1 \
%if "%{_lib}" == "lib64"
-DWANT_LIB64=1 \
%endif
../

make %{?_smp_mflags} VERBOSE=1
cd ..

# Build devel docs
doxygen

%install
pushd build
%makeinstall DESTDIR=%{buildroot}
popd

# Install devel docs (do it manually to fix also rpmlint warning "files-duplicate" with %%fdupes)
mkdir -p %{buildroot}%{_docdir}/libpodofo-devel
install -pm 0644 AUTHORS COPYING.LIB ChangeLog FAQ.html README.html TODO %{buildroot}%{_docdir}/libpodofo-devel/
cp -a doc/html/ %{buildroot}%{_docdir}/libpodofo-devel/

%fdupes -s %{buildroot}

%post -n libpodofo%{libver} -p /sbin/ldconfig

%postun -n libpodofo%{libver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING README.html
%{_bindir}/*
%doc %{_mandir}/man1/podofo*.1%{ext_man}

%files -n libpodofo%{libver}
%defattr(-,root,root,-)
%{_libdir}/libpodofo.so.%{version}

%files -n libpodofo-devel
%defattr(-,root,root,-)
%doc %{_docdir}/libpodofo-devel/
%{_includedir}/podofo/
%{_libdir}/libpodofo.so

%changelog
* Mon Sep 15 2014 crrodriguez@opensuse.org
- Just use "lua-devel" as BuildRequires current versions
  support lua 5.2
* Sat Jul 12 2014 plinnell@suse.com
- Update to 0.9.3
  +  OSX build fixes
  +  Fixed AES decryption
  +  Improved load of (broken) PDF files
  +  Sign PDF file as an incremental update
  +  Added partial support for Type3 font encoding and metrics
  +  Drawing API improvements
  +  Unicode file names for attachments
  +  Font subset embedding
  +  Many compiler warnings squashed
- Dropped podofo-0.9.2-soname.patch which is upstream
- Dropped remove-internal-findfreetype-references.patch
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Added remove-internal-findfreetype-references.patch: fixes build
  with freetype2 2.5.1 as internal copy is broken. It is also better
  practice to use cmake's FindPackage modules
* Sun Mar 31 2013 asterios.dramis@gmail.com
- Update to version 0.9.2:
  * Many bug fixes which were made over the last two years.
  * New encryption support based on OpenSSL. OpenSSL is now a mandatory
    requirement.
- Removed podofobox.1_fix.patch (not needed anymore).
- Added a patch (podofo-0.9.2-soname.patch) to update the soname of the library
  (http://sourceforge.net/apps/mantisbt/podofo/view.php?id=54).
- Added build requirements libcppunit-devel and libidn-devel.
- Build the devel docs (added doxygen build requirement).
* Mon Jan  7 2013 mrdocs@opensuse.org
- fix build on SLES
* Sat Mar 17 2012 dimstar@opensuse.org
- Change lua-devel BuildRequires to lua51-devel on openSUSE > 12.1:
  the code is not ready to work with lua 5.2.
* Tue Nov 29 2011 ro@suse.de
- use _lib macro to properly determine lib suffix
* Wed May 25 2011 asterios.dramis@gmail.com
- Update to version 0.9.1:
  * Bug fixes and optimizations.
  * Added a man page for podofogc.
  From 0.9.0:
  * Lot's of bug fixes for PDF parsing, PDF creation and in several other
    areas.
  * New compact write mode to create slightly smaller PDF files.
  * Initial PDF signature support.
  * Support for the 14 standard Type1 fonts.
  * Improved font and encoding support (e.g. creation of fonts from existing
    objects).
  * New tools, e.g. podofocolor.
- Spec files updates:
  * Changes based on spec-cleaner run.
  * Changes in License.
  * Updates in Group:, Summary: and %%description entries.
  * Updates in %%build section for lib64 compilation.
  * Minor other updates.
- Added a patch for podofobox.1 to fix an rpmlint warning.
* Thu Oct 28 2010 mrdocs@opensuse.org
-version update to 0.8.4
  * Build fixes for various plaforms - mostly for  Windows/VS2008
* Thu Oct 21 2010 mrdocs@opensuse.org  
-new version 0.8.3
  * Added a new write mode for PDFs, which is default, to create
    more compact PDFs;
  * Extended several APIs, e.g. image interpolation support,
    image chroma key support, or selection of base14 fonts
  * Fixed bugs in the predictor implementation
  * Fixed encryption of unicode strings
  * Fixed namestree implementation (root shall not have a Limits key)
  * Fixed detection of inline image data and support for inline images larger than 4KB
  * Several optimizations, bugs fixes and fixed a minor memory leak
* Thu Sep  9 2010 mrdocs@opensuse.org
-more spec file cleanups
-add missing libpng-devel
* Thu Sep  9 2010 mrdocs@opensuse.org
-version bump to 0.8.2
-many many bug fixes and build issues
-add lua-devel, which adds imposition capabilites
* Thu Jul  1 2010 toms@suse.de
- Corrected licence
* Tue May 11 2010 toms@suse.de
- Updated to 0.8.0, taken patches from hgraeber
  . remove so number form devel package
* Tue Jul 28 2009 toms@suse.de
- Taken from home:/mrdocs and corrected SPEC file:
  . Added typical SUSE header
  . Install section now contains the correct lines
  . Changed devel package name to libpodofo0_6_99-devel
  . Create this .changes file
  Thu Jan 01 00:00:00 CEST 2009 - mrdocs at opensuse.org
- 0.7.0 release
* Sat Oct  4 2008 hub@figuiere.net
- Package closer to policies: split.
  Mon Jul 05 00:00:00 CEST 2008 - mrdocs at opensuse.org
- 0.6 release
  Sat Jul 12 00:00:00 CEST 2008 - mrdocs at opensuse.org
- new svn snapshot of upcoming 0.6.0
- add openssl-devel dependency
- 64 bit builds fixed
  Mon Aug 27 00:00:00 CEST 2007 - mrdocs at opensuse.org
- enable debug package
  Wed Aug 08 00:00:00 CEST 2007 - mrdocs at opensuse.org
- revert back to 0.5.0 as the API is unstable
  Tue Aug 01 00:00:00 CEST 2007 - mrdocs at scribus.info
- new svn snapshot with 64 bit build support
  Thu Jul 26 00:00:00 CEST 2007 - mrdocs at scribus.info
- version upgrade
- use cmake as autotools are no longer supported
* Mon Dec 25 2006 Bernhard Walle <bwalle@suse.de>
- initial package
